
Filter tracings for a variety of cameras

Each filter should be in the same format.

A two column file. The zeroth column is wavelength in metres, the first
column is transparency. 0 transparency means the filter is opaque at that wavelength
1 means transparent.

The filename is 
{series}_{band}.dat

eg sloan_u.dat, or miri_f1000w.dat
